@@ -56,6 +56,7 @@ use base qw( SVK::Command::Commit );
 use SVK::XD;
 use SVK::I18N;
 use SVK::Command::Log;
+use SVK::Logger;
 use SVK::Merge;
 use SVK::Util qw( get_buffer_from_editor traverse_history );
 
@@ -169,8 +170,8 @@ sub run {
 	$merge = SVK::Merge->auto (%$self, repos => $repos, target => '',
 				   ticket => !$self->{no_ticket},
 				   src => $src, dst => $dst);
-	print $merge->info;
-	print $merge->log(1) if $self->{summary};
+	$logger->info( $merge->info);
+	$logger->info( $merge->log(1)) if $self->{summary};
     }
     else {
 	die loc("Incremental merge not supported\n") if $self->{incremental};
@@ -188,7 +189,7 @@ sub run {
 
     $merge->{notice_copy} = 1;
     if ($merge->{fromrev} == $merge->{src}->revision) {
-	print loc ("Empty merge.\n");
+	$logger->info( loc ("Empty merge."));
 	return;
     }
 
@@ -198,7 +199,7 @@ sub run {
     if ($self->{incremental}) {
 	die loc ("Not possible to do incremental merge without a merge ticket.\n")
 	    if $self->{no_ticket};
-	print loc ("-m ignored in incremental merge\n") if $self->{message};
+	$logger->info( loc ("-m ignored in incremental merge")) if $self->{message};
 	my @rev;
 
         traverse_history (
@@ -226,7 +227,7 @@ sub run {
 		$merge->{fromrev} = $previous_base;
 	    }
 
-	    print '===> '.$merge->info;
+	    $logger->info( '===> '.$merge->info);
 	    $self->{message} = $merge->log (1);
 	    $self->decode_commit_message;
 
