@@ -55,6 +55,7 @@ use SVK::Version;  our $VERSION = $SVK::VERSION;
 use base qw( SVK::Command::Commit );
 use SVK::I18N;
 use SVK::Util qw( is_uri get_prompt traverse_history );
+use SVK::Logger;
 
 use constant narg => undef;
 
@@ -102,12 +103,13 @@ sub run {
         }
     );
 
-    print loc("Mirror initialized.  Run svk sync %1 to start mirroring.\n", $target->report);
+    $logger->info( loc("Mirror initialized.  Run svk sync %1 to start mirroring.\n", $target->report));
 
     return;
 }
 
 package SVK::Command::Mirror::relocate;
+use SVK::Logger;
 use base qw(SVK::Command::Mirror);
 use SVK::I18N;
 
@@ -121,7 +123,7 @@ sub run {
 
     $m->relocate($source, @options);
 
-    print loc("Mirror relocated.\n");
+    $logger->info( loc("Mirror relocated."));
     return;
 }
 
@@ -129,6 +131,7 @@ package SVK::Command::Mirror::detach;
 use base qw(SVK::Command::Mirror);
 use SVK::I18N;
 
+use SVK::Logger;
 use constant narg => 1;
 
 sub run {
@@ -139,38 +142,41 @@ sub run {
     die loc("%1 is inside a mirrored path.\n", $target->depotpath) if $mpath;
 
     $m->detach(1); # remove svm:source and svm:uuid too
-    print loc("Mirror path '%1' detached.\n", $target->depotpath);
+    $logger->info( loc("Mirror path '%1' detached.\n", $target->depotpath));
     return;
 }
 
 package SVK::Command::Mirror::upgrade;
 use base qw(SVK::Command::Mirror);
 use SVK::I18N;
+use SVK::Logger;
 
 use constant narg => 1;
 
 sub run {
     my ($self, $target) = @_;
-    print loc("nothing to upgrade\n");
+    $logger->info( loc("nothing to upgrade"));
     return;
 }
 
 package SVK::Command::Mirror::unlock;
 use base qw(SVK::Command::Mirror);
 use SVK::I18N;
+use SVK::Logger;
 
 use constant narg => 1;
 
 sub run {
     my ($self, $target) = @_;
     $target->depot->mirror->unlock($target->path_anchor);
-    print loc ("mirror locks on %1 removed.\n", $target->report);
+    $logger->info( loc ("mirror locks on %1 removed.\n", $target->report));
     return;
 }
 
 package SVK::Command::Mirror::list;
 use base qw(SVK::Command::Mirror);
 use SVK::I18N;
+use SVK::Logger;
 use List::Util qw( max );
 
 sub parse_arg {
@@ -208,10 +214,10 @@ sub run {
     my $max_uri        = max map { length $_->[1] } @mirror_columns;
 
     my $fmt = "%-${max_depot_path}s   %-s\n";
-    printf $fmt, loc('Path'), loc('Source');
-    print '=' x ( $max_depot_path + $max_uri + 3 ), "\n";
+    $logger->info(sprintf $fmt, loc('Path'), loc('Source'));
+    $logger->info( '=' x ( $max_depot_path + $max_uri + 3 ));
 
-    printf $fmt, @$_ for @mirror_columns;
+    $logger->info(sprintf $fmt, @$_ )for @mirror_columns;
 
     return;
 }
@@ -295,7 +301,7 @@ sub recover_headrev {
         propset => { direct  => 1, revprop => 1 },
     )->run($_ => $props->{$_}, $target) for sort grep {m/^sv[nm]/} keys %$props;
 
-    print loc("Mirror state successfully recovered.\n");
+    $logger->info( loc("Mirror state successfully recovered."));
     return;
 }
 
@@ -311,7 +317,7 @@ sub recover_list_entry {
         $self->arg_depotpath ('/'.$target->depotname.'/'),
     );
 
-    print loc("%1 added back to the list of mirrored paths.\n", $target->report);
+    $logger->info( loc("%1 added back to the list of mirrored paths.\n", $target->report));
     return;
 }
 
