@@ -52,6 +52,7 @@ package SVK::Merge;
 use strict;
 use SVK::Util qw(traverse_history is_path_inside);
 use SVK::I18N;
+use SVK::Merge::Info;
 use SVK::Editor::Merge;
 use SVK::Editor::Rename;
 use SVK::Editor::Translate;
@@ -116,42 +117,44 @@ sub new {
 sub auto {
     my $self = new (@_);
     @{$self}{qw/base fromrev/} = $self->find_merge_base(@{$self}{qw/src dst/});
-    $self->_rebase;
 
     return $self;
 }
 
-sub _rebase {
+sub _rebase2 {
     my $self = shift;
+    my ($src, $dst, $base) = @_;
 
-    return unless $self->{base}->path eq $self->{dst}->path;
+    return unless $base->path eq $dst->path;
 
-    $self->{src}->is_merged_from($self->{base})
+    $src->is_merged_from($base)
 	or return;
 
-    my $dst = $self->{src}->prev or return;
-    $dst->root->check_path($dst->path) or return;
+    my $ddst = $src->prev or return;
+    $ddst->root->check_path($ddst->path) or return;
 
     # If the previous source hasn't been merged, use the original base
     # logic.  Otherwise we are merging changes between the alleged
     # merge and actual revision.
-    $self->{dst}->is_merged_from($dst) or return;
+    $dst->is_merged_from($ddst) or return;
 
     require SVK::Path::Txn;
-    $dst = $dst->clone;
-    bless $dst, 'SVK::Path::Txn'; # XXX: need a saner api for this
+    $ddst = $ddst->clone;
+    bless $ddst, 'SVK::Path::Txn'; # XXX: need a saner api for this
 
     my $xmerge = SVK::Merge->auto(%$self, quiet => 1,
-				  src => $self->{base},
-				  dst => $dst);
+				  src => $base,
+				  dst => $ddst);
 
     my ($editor, $inspector, %cb) = $xmerge->{dst}->get_editor();
     local $ENV{SVKRESOLVE} = 's';
     unless ($xmerge->run( $editor, inspector => $inspector, %cb )) {
 	# XXX why isn't the txnroot uptodate??
-	$self->{base} = $xmerge->{dst};
-	$self->{base}->inspector->root($self->{base}->txn->root($self->{base}->pool));
+        my $new_base = $xmerge->{dst};
+	$new_base->inspector->root($new_base->txn->root($new_base->pool));
+        return $new_base;
     }
+    return;
 }
 
 # DEPRECATED
@@ -227,6 +230,11 @@ sub find_merge_base {
 		$rev);
     }
 
+    return ($src->new (revision => $merge_baserev), $merge_baserev)
+        if $merge_baserev;
+
+    my @preempt_result;
+
     for (grep {exists $srcinfo->{$_} && exists $dstinfo->{$_}}
 	 (sort keys %{ { %$srcinfo, %$dstinfo } })) {
 	my ($path) = m/:(.*)$/;
@@ -241,17 +249,30 @@ sub find_merge_base {
 	    next unless $src->related_to($src->as_depotpath->seek_to($rev));
 	}
 
-	if ($path eq $dst->path &&
-	    (my $src_base = $src->is_merged_from($src->mclone(path => $path, revision => $rev)))) {
-	    ($basepath, $baserev, $baseentry) = ($path, $rev, $_);
-	    last;
-	}
-	($basepath, $baserev, $baseentry) = ($path, $rev, $_)
-	    if !$basepath || $fs->revision_prop($rev, 'svn:date') gt $fs->revision_prop($baserev, 'svn:date');
+        if (!$basepath || $fs->revision_prop($rev, 'svn:date') gt $fs->revision_prop($baserev, 'svn:date')) {
+            ($basepath, $baserev, $baseentry) = ($path, $rev, $_);
+            if ($path eq $dst->path &&
+                $src->is_merged_from($dst->mclone(revision => $rev))) {
+
+                my ($base, $from) = $self->_mk_base_and_from( $src, $dstinfo, $basepath, $baserev );
+                # this takes precedence than other potential base or
+                # rebasable base that is on src.
+                if (my $rebased = $self->_rebase2( $src, $dst, $base)) {
+                    return ($rebased, $from);
+                }
+            }
+            elsif ($path eq $src->path && $dst->is_merged_from($src->mclone(revision => $rev))) {
+                my ($base, $from) = $self->_mk_base_and_from( $src, $dstinfo, $basepath, $baserev );
+                $base = $self->_rebase2( $dst, $src, $base) || $base;
+                @preempt_result = ($base, $from);
+            }
+            else {
+                @preempt_result = ();
+            }
+        }
     }
 
-    return ($src->new (revision => $merge_baserev), $merge_baserev)
-        if $merge_baserev;
+    return @preempt_result if @preempt_result;
 
     unless ($basepath) {
 	return ($src->new (path => '/', revision => 0), 0)
@@ -273,6 +294,12 @@ sub find_merge_base {
 		if $minfo->subset_of ($srcinfo) && $minfo->subset_of ($dstinfo);
 	}
     }
+    return $self->_mk_base_and_from( $src, $dstinfo, $basepath, $baserev );
+}
+
+sub _mk_base_and_from {
+    my $self = shift;
+    my ($src, $dstinfo, $basepath, $baserev) = @_;
 
     my $base = $src->as_depotpath->new
 	(path => $basepath, revision => $baserev, targets => undef);
@@ -281,7 +308,7 @@ sub find_merge_base {
 
     # When /A:1 is copied to /B:2, then removed, /B:2 copied to /A:5
     # the fromrev shouldn't be /A:1, as it confuses the copy detection during merge.
-    my $from = $dstinfo->{$fs->get_uuid.':'.$src->path};
+    my $from = $dstinfo->{$src->depot->repos->fs->get_uuid.':'.$src->path};
     if ($from) {
 	my ($toroot, $fromroot) = $src->nearest_copy;
 	$from = 0 if $toroot && $from < $toroot->revision_root_revision;
@@ -345,20 +372,29 @@ sub find_merge_sources {
     return $minfo;
 }
 
+sub _get_new_ticket {
+    my ($self, $srcinfo) = @_;
+    my $dstinfo = $self->merge_info($self->{dst});
+    # We want the ticket representing src, but not dst.
+    return $dstinfo->union ($srcinfo)->del_target($self->{dst});
+}
+
+# deprecated
 sub get_new_ticket {
     my ($self, $srcinfo) = @_;
-    my $dstinfo = $self->merge_info ($self->{dst});
-    # We want the ticket representing src, but not dst.
-    my $newinfo = $dstinfo->union ($srcinfo)->del_target ($self->{dst});
-    unless ($self->{quiet}) {
-	for (sort keys %$newinfo) {
-	    $logger->info(loc("New merge ticket: %1:%2", $_, $newinfo->{$_}{rev}))
-		if !$dstinfo->{$_} || $newinfo->{$_}{rev} > $dstinfo->{$_}{rev};
-	}
-    }
+    my $newinfo = $self->_get_new_ticket($srcinfo);
+    $self->print_new_ticket($newinfo);
     return $newinfo->as_string;
 }
 
+sub print_new_ticket {
+    my ($self, $dstinfo, $newinfo) = @_;
+    for (sort keys %$newinfo) {
+	$logger->info(loc("New merge ticket: %1:%2", $_, $newinfo->{$_}{rev}))
+	    if !$dstinfo->{$_} || $newinfo->{$_}{rev} > $dstinfo->{$_}{rev};
+    }
+}
+
 sub log {
     my ($self, $no_separator) = @_;
     open my $buf, '>', \ (my $tmp = '');
@@ -528,9 +564,12 @@ sub run {
     # $cb{inspector} = $self->{dst}->inspector
     # unless ref($cb{inspector}) eq 'SVK::Inspector::Compat' ;
 
+    my $dstinfo = $self->merge_info($self->{dst});
+
     my $meditor = SVK::Editor::Merge->new
 	( anchor => $src->path_anchor,
 	  repospath => $src->repospath, # for stupid copyfrom url
+	  static_inspector => $self->{dst}->inspector,
 	  base_anchor => $base->path_anchor,
 	  base_root => $base_root,
 	  target => $target,
@@ -554,8 +593,18 @@ sub run {
 					(SVK::Merge::Info->new ($prop->{local}))->as_string);
 			    }
 			},
-	    ticket => 
-	    sub { $self->get_new_ticket ($self->merge_info_with_copy ($src)->add_target ($src)) }
+	    ticket =>
+	    $self->_get_new_ticket($self->merge_info_with_copy($src)->add_target($src)),
+	    cb_merged => sub {
+		my ($changes, $type, $ticket) = @_;
+		if (!$changes) { # rollback all ticket
+		    my $func = "change_${type}_prop";
+		    my $baton = $storage->open_root ($cb{cb_rev}->($cb{target}||''));
+		    $storage->$func( $baton, 'svk:merge', undef );
+		    return;
+		}
+		$self->print_new_ticket( $dstinfo, $ticket ) unless $self->{quiet};
+	    }
 	  ) :
 	  ( prop_resolver => { 'svk:merge' => sub { ('G', undef, 1)} # skip
 			     }),
@@ -578,8 +627,18 @@ sub run {
 	    my $usrc = $src->universal;
 	    my $srckey = join(':', $usrc->{uuid}, $usrc->{path});
 	    if ($dstinfo->{$srckey}) {
+                # find which rev on src is merged from the base.
 		$boundry_rev = $src->merged_from
 		    ($self->{base}, $self, $self->{base}{path});
+                # however if src is removed and later copied again
+                # from base, we need the later one as boundry
+                my $t = $src;
+                while (my ($toroot, $fromroot, $path) = $t->nearest_copy) {
+                    if ($path eq $self->{base}->path_anchor) {
+                        $boundry_rev = List::Util::max( grep { defined $_ } $boundry_rev, $toroot->revision_root_revision );
+                    }
+                    $t = $t->mclone( path => $path, revision => $fromroot->revision_root_revision );
+                }
 	    }
 	    else {
 		# when did the branch first got created?
@@ -715,93 +774,14 @@ sub resolver {
 			      external => $ENV{SVKMERGE});
 }
 
-package SVK::Merge::Info;
-
-sub new {
-    my ($class, $merge) = @_;
-    my $minfo = { map { my ($uuid, $path, $rev) = m/(.*?):(.*):(\d+$)/;
-			("$uuid:$path" => SVK::Target::Universal->new ($uuid, $path, $rev))
-		    } grep { length $_ } split (/\n/, $merge || '') };
-    bless $minfo, $class;
-    return $minfo;
-}
-
-sub add_target {
-    my ($self, $target) = @_;
-    $target = $target->universal
-	if $target->can('universal');
-    $self->{$target->ukey} = $target;
-    return $self;
-}
-
-sub del_target {
-    my ($self, $target) = @_;
-    $target = $target->universal
-	if $target->can('universal');
-    delete $self->{$target->ukey};
-    return $self;
-}
-
-sub remove_duplicated {
-    my ($self, $other) = @_;
-    for (keys %$other) {
-	if ($self->{$_} && $self->{$_}{rev} <= $other->{$_}{rev}) {
-	    delete $self->{$_};
-	}
-    }
-    return $self;
-}
-
-sub subset_of {
-    my ($self, $other) = @_;
-    my $subset = 1;
-    for (keys %$self) {
-	return unless exists $other->{$_} && $self->{$_}{rev} <= $other->{$_}{rev};
-    }
-    return 1;
-}
-
-sub union {
-    my ($self, $other) = @_;
-    # bring merge history up to date as from source
-    my $new = SVK::Merge::Info->new;
-    for (keys %{ { %$self, %$other } }) {
-	if ($self->{$_} && $other->{$_}) {
-	    $new->{$_} = $self->{$_}{rev} > $other->{$_}{rev}
-		? $self->{$_} : $other->{$_};
-	}
-	else {
-	    $new->{$_} = $self->{$_} ? $self->{$_} : $other->{$_};
-	}
-    }
-    return $new;
-}
-
-sub resolve {
-    my ($self, $depot) = @_;
-    my $uuid = $depot->repos->fs->get_uuid;
-    return { map { my $local = $self->{$_}->local($depot);
-		   $local ? ("$uuid:".$local->path_anchor => $local->revision) : ()
-	       } keys %$self };
-}
-
-sub verbatim {
-    my ($self) = @_;
-    return { map { $_ => $self->{$_}{rev} } keys %$self };
-}
-
-sub as_string {
-    my $self = shift;
-    return join ("\n", map {"$_:$self->{$_}{rev}"} sort keys %$self);
-}
-
 =head1 TODO
 
 Document the merge and ticket tracking mechanism.
 
 =head1 SEE ALSO
 
-L<SVK::Editor::Merge>, L<SVK::Command::Merge>, Star-merge from GNU Arch
+L<SVK::Editor::Merge>, L<SVK::Command::Merge>, L<SVK::Merge::Info>, Star-merge
+from GNU Arch
 
 =cut
 
