@@ -242,17 +242,21 @@ sub create_depots {
 	    qr/^[yn]/i,
 	);
 	next if $ans =~ /^n/i;
-
-        make_path(dirname($path));
-
-	SVN::Repos::create($path, undef, undef, undef,
-			   {'fs-type' => $ENV{SVNFSTYPE} || 'fsfs',
-			    'bdb-txn-nosync' => '1',
-			    'bdb-log-autoremove' => '1'});
+        $self->_create_depot($path)
     }
     return;
 }
 
+sub _create_depot {
+    my ($self, $path) = @_;
+    make_path(dirname($path));
+
+    SVN::Repos::create($path, undef, undef, undef,
+                       {'fs-type' => $ENV{SVNFSTYPE} || 'fsfs',
+                        'bdb-txn-nosync' => '1',
+                        'bdb-log-autoremove' => '1'});
+}
+
 
 =item store
 
@@ -989,7 +993,7 @@ sub _delta_rev {
     my $entry = $arg->{cinfo};
     my $schedule = $entry->{'.schedule'} || '';
     # XXX: uncomment this as mutation coverage test
-    # return $cb_resolve_rev->($arg->{path}, $entry->{revision});
+    # return  $entry->{revision};
 
     # Lookup the copy source rev for the case of open_directory inside
     # add_directotry with history.  But shouldn't do so for replaced
@@ -998,7 +1002,7 @@ sub _delta_rev {
 	$self->_copy_source($entry, $arg->{copath}) : ();
     ($source_path, $source_rev) = ($arg->{path}, $entry->{revision})
 	unless defined $source_path;
-    return $arg->{cb_resolve_rev}->($source_path, $source_rev);
+    return $source_rev;
 }
 
 sub _delta_content {
@@ -1177,12 +1181,12 @@ sub _node_type {
     my $st = [lstat ($copath)];
     return '' if !-e _;
     unless (-r _) {
-	$logger->warn( loc ("Warning: $copath is unreadable."));
+	$logger->warn( loc ("Warning: %1 is unreadable.", $copath));
 	return;
     }
     return ('file', $st) if -f _ or is_symlink;
     return ('directory', $st) if -d _;
-    $logger->warn( loc ("Warning: unsupported node type $copath."));
+    $logger->warn( loc ("Warning: unsupported node type %1.", $copath));
     return ('', $st);
 }
 
@@ -1510,18 +1514,16 @@ sub checkout_delta {
     $arg{editor} = SVK::Editor::Delay->new ($arg{editor})
 	   unless $arg{nodelay};
 
-    my $cb_resolve_rev = $arg{cb_resolve_rev} ||= sub { $_[1] };
     # XXX: translate $repospath to use '/'
     $arg{cb_copyfrom} ||= $arg{expand_copy} ? sub { (undef, -1) }
 	: sub { my $path = $_[0]; $path =~ s/%/%25/g; ("file://$repospath$path", $_[1]) };
-    my ($entry) = $self->get_entry($arg{copath}, 1);
-    my $rev = $arg{cb_resolve_rev}->($arg{path}, $entry->{revision});
     local $SIG{INT} = sub {
 	$arg{editor}->abort_edit;
 	die loc("Interrupted.\n");
     };
 
-    my $baton = $arg{editor}->open_root ($rev);
+    my ($entry) = $self->get_entry($arg{copath}, 1);
+    my $baton = $arg{editor}->open_root ($entry->{revision});
     $self->_delta_dir (%arg, baton => $baton, root => 1, base => 1, type => 'directory');
     $arg{editor}->close_directory ($baton);
     $arg{editor}->close_edit ();
